@@ -38,6 +38,7 @@ describe 'neutron::agents::l3' do
       should contain_neutron_l3_agent_config('DEFAULT/periodic_interval').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('DEFAULT/periodic_fuzzy_delay').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('DEFAULT/enable_metadata_proxy').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_l3_agent_config('DEFAULT/radvd_user').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('agent/availability_zone').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('agent/extensions').with_value('<SERVICE DEFAULT>')
     end
@@ -88,6 +89,16 @@ describe 'neutron::agents::l3' do
       end
     end
 
+    context 'with radvd user' do
+      before :each do
+        params.merge!(:radvd_user => 'root')
+      end
+
+      it 'configures radvd user' do
+        should contain_neutron_l3_agent_config('DEFAULT/radvd_user').with_value(p[:radvd_user])
+      end
+    end
+
     context 'with HA routers' do
       before :each do
         params.merge!(:ha_enabled            => true,
@@ -109,26 +120,6 @@ describe 'neutron::agents::l3' do
         should contain_neutron_l3_agent_config('agent/availability_zone').with_value(p[:availability_zone])
       end
     end
-
-    context 'with extensions in string' do
-      before :each do
-        params.merge!(:extensions => 'fip_qos,gateway_ip_qos,port_forwarding')
-      end
-
-      it 'configures extentions' do
-        should contain_neutron_l3_agent_config('agent/extensions').with_value('fip_qos,gateway_ip_qos,port_forwarding')
-      end
-    end
-
-    context 'with extensions in array' do
-      before :each do
-        params.merge!(:extensions => ['fip_qos', 'gateway_ip_qos', 'port_forwarding'])
-      end
-
-      it 'configures extentions' do
-        should contain_neutron_l3_agent_config('agent/extensions').with_value('fip_qos,gateway_ip_qos,port_forwarding')
-      end
-    end
   end
 
   shared_examples 'neutron::agents::l3 on Debian' do
